# GitLab Project Generator

This Python script automates the process of creating GitLab projects in bulk for students. It's indended to be used to automatically add members to each project based on a webreg export of the student sign up list.

The basic idea is to keep all GitLab projects related to a specific course under a single namespace, rather than have students invite you to their projects, which can clutter up your workspace. It also means that you can use your preferred naming conventions for the projects to keep things neat. It also allows you to set up a basic template structure to be used for all projects, like including a `.gitignore`-file.

GitLab supports various webhooks that allow you to notify some service when a given event is triggered. Setting these up manually for projects can be tedious, but when they are managed on a group level the process is greatly simplified. A simple way of keeping track of course submissions is to require the students to tag each of their submissions (e.g., `lab1-v.1.0`) and set up triggers that reports only when a new `tag` is created. 

For example, to add a webhook for a Microsoft Teams channel, bring up the options for the channel, click `Connectors`, configure an incoming webhook and copy the URL. Next, head over to the GitLab sub-group and add the URL to `Settings/Integrations/Microsoft Teams notifications` and set it to notify only when a tag is pushed or removed. The Teams channel will now be notified whenever a tag is created in any of the group's projects.  

# Basic usage

1. Create a local file called `.env` and add your GitLab API token:
```
  # User token for gitlab.liu.se
  token=<secret-gitlab-token>
```

2. Install the Python libs. For example, using a virtual environment:
```bash
$ python3 -m venv myenv
$ source myenv/bin/activate
$ pip3 install -r requirements.txt
```

3. (optional) Export the sign up list from [webreg3](`https://www.ida.liu.se/webreg3/`) and save it as as a text file. The file should be of the format:
```csv
bobdy01:Bob:Dylan:4105240101:ABC123:LAB:A:1
johdo04:John:Doe:2701010001:ABC123:LAB:A:1
jando04:Jane:Doe:2701010002:ABC123:LAB:B:1
...
```

5. Configure your `config.yml` file (see an example configuration in `config-example.yml`).

6. Run the script:
```bash
$ python3 main.py config.yml
```
*Note:* The script can be run again with an updated list of members in the sign up file as more students register in webreg. Existing projects will never be re-created and members will never be removed from a group. If a student changes group this needs to be handled manually.


# Example of generated project structure

![generated example project](screenshot.png)