import os
import sys
from utils import *
import yaml
from dotenv import load_dotenv

def main(config_file):
    with open(config_file, "r") as stream:
        load_dotenv()
        token = os.getenv('token')
        webhook = os.getenv('webhook')
        
        config = dotdict(yaml.safe_load(stream))
        
        # Authentication headers
        headers = {'Authorization': f"Bearer {token}" }

        # Create main group
        namespace_id = create_group(
            config.groups.main.name,
            config.groups.main.path,
            config.groups.main.description,
            headers,
            config.general.api_url)


        # Create subgroup
        if config.groups.sub:
            namespace_id = create_subgroup(
                config.groups.sub.name,
                config.groups.sub.path,
                config.groups.sub.description,
                namespace_id,
                headers,
                config.general.api_url)

        # Generate projects
        if config.projects.groups:
            generate_projects(
                config.projects.groups.prefixes,
                config.projects.groups.suffixes,
                namespace_id,
                config.projects.template_url,
                headers,
                config.general.api_url)
    
        # Add members to projects
        if config.projects.members:
            add_members(
                config.projects.members.path,
                namespace_id,
                headers,
                config.general.api_url,
                config.projects.template_url,
                config.projects.members.init_projects)


if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Please provide a path to a configuration file (e.g. config.yml)")
        sys.exit(0)
    
    # Run main
    main(sys.argv[1])